@@ -17,7 +17,7 @@
 #    You should have received a copy of the GNU General Public License
 #    along with emid.  If not, see <http://www.gnu.org/licenses/>.
 
-import fnmatch, os, random, signal, time
+import fnmatch, logging, os, platform, random, signal, time, traceback
 import numpy as np
 import pandas as pd
 from emid.pyqtver import*
@@ -27,17 +27,17 @@ from emid._version_info import*
 from emid.audio_manager import*
 from emid.global_parameters import*
 from emid.dialog_edit_preferences import*
-from emid.dialog_edit_phones import*
+from emid.dialog_edit_transducers import*
 
 if pyqtversion == 5:
     from PyQt5 import QtCore, QtGui
     from PyQt5.QtCore import Qt, QEvent, QDate, QDateTime, QTime
-    from PyQt5.QtWidgets import QAction, QCheckBox, QComboBox, QDesktopWidget, QFrame, QFileDialog, QGridLayout, QHBoxLayout, QInputDialog, QLabel, QLayout, QLineEdit, QMainWindow, QMessageBox, QScrollArea, QSizePolicy, QSlider, QSpacerItem, QSplitter, QPushButton, QToolButton, QVBoxLayout, QWhatsThis, QWidget
+    from PyQt5.QtWidgets import QAction, QCheckBox, QComboBox, QDesktopWidget, QDialog, QDialogButtonBox, QFrame, QFileDialog, QGridLayout, QHBoxLayout, QInputDialog, QLabel, QLayout, QLineEdit, QMainWindow, QMessageBox, QScrollArea, QSizePolicy, QSlider, QSpacerItem, QSplitter, QPushButton, QToolButton, QVBoxLayout, QWhatsThis, QWidget
     from PyQt5.QtGui import QColor, QDesktopServices, QDoubleValidator, QIcon, QPainter, QIntValidator
 elif pyqtversion == 6:
     from PyQt6 import QtCore, QtGui
     from PyQt6.QtCore import Qt, QEvent, QDate, QDateTime, QTime
-    from PyQt6.QtWidgets import  QCheckBox, QComboBox, QFrame, QFileDialog, QGridLayout, QHBoxLayout, QInputDialog, QLabel, QLayout, QLineEdit, QMainWindow, QMessageBox, QScrollArea, QSizePolicy, QSlider, QSpacerItem, QSplitter, QPushButton, QToolButton, QVBoxLayout, QWhatsThis, QWidget
+    from PyQt6.QtWidgets import  QCheckBox, QComboBox, QDialog, QDialogButtonBox, QFrame, QFileDialog, QGridLayout, QHBoxLayout, QInputDialog, QLabel, QLayout, QLineEdit, QMainWindow, QMessageBox, QScrollArea, QSizePolicy, QSlider, QSpacerItem, QSplitter, QPushButton, QToolButton, QVBoxLayout, QWhatsThis, QWidget
     from PyQt6.QtGui import QAction, QColor, QDesktopServices, QDoubleValidator, QIcon, QPainter, QIntValidator
     
 QtCore.Signal = QtCore.pyqtSignal
@@ -45,6 +45,69 @@ QtCore.Slot = QtCore.pyqtSlot
 
 signal.signal(signal.SIGINT, signal.SIG_DFL)
 
+local_dir = os.path.expanduser("~") +'/.local/share/data/emid/'
+if os.path.exists(local_dir) == False:
+    os.makedirs(local_dir)
+stderrFile = os.path.expanduser("~") +'/.local/share/data/emid/emid_stderr_log.txt'
+
+logging.basicConfig(filename=stderrFile,level=logging.DEBUG,)
+
+# def excepthook(except_type, except_val, tbck):
+#     """ Show errors in message box"""
+#     # recover traceback
+#     tb = traceback.format_exception(except_type, except_val, tbck)
+#     ret = QMessageBox.critical(None, "Critical Error! Something went wrong, the following info may help you troubleshooting",
+#                                     ''.join(tb),
+#                                     QMessageBox.StandardButton.Ok)
+#     timeStamp = ''+ time.strftime("%d/%m/%y %H:%M:%S", time.localtime()) + ' ' + '\n'
+#     logMsg = timeStamp + ''.join(tb)
+#     logging.debug(logMsg)
+
+#the except hook allows to see most startup errors in a window
+#rather than the console
+def excepthook(except_type, except_val, tbck):
+    """ Show errors in message box"""
+    # recover traceback
+    tb = traceback.format_exception(except_type, except_val, tbck)
+    def onClickSaveTbButton():
+        ftow = QFileDialog.getSaveFileName(None, 'Choose where to save the traceback', "traceback.txt", 'All Files (*)')[0]
+        if len(ftow) > 0:
+            if fnmatch.fnmatch(ftow, '*.txt') == False:
+                ftow = ftow + '.txt'
+            fName = open(ftow, 'w')
+            fName.write("".join(tb))
+            fName.close()
+    
+    diag = QDialog(None, Qt.WindowType.CustomizeWindowHint | Qt.WindowType.WindowCloseButtonHint)
+    diag.window().setWindowTitle("Critical Error!")
+    siz = QVBoxLayout()
+    lay = QVBoxLayout()
+    saveTbButton = QPushButton("Save Traceback", diag)
+    saveTbButton.clicked.connect(onClickSaveTbButton)
+    lab = QLabel("Sorry, something went wrong. The attached traceback can help you troubleshoot the problem: \n\n" + "".join(tb))
+    lab.setMargin(10)
+    lab.setWordWrap(True)
+    lab.setTextInteractionFlags(Qt.TextInteractionFlag.TextSelectableByMouse)
+    lab.setStyleSheet("QLabel { background-color: white }");
+    lay.addWidget(lab)
+
+    sc = QScrollArea()
+    sc.setWidget(lab)
+    siz.addWidget(sc) #SCROLLAREA IS A WIDGET SO IT NEEDS TO BE ADDED TO A LAYOUT
+
+    buttonBox = QDialogButtonBox(QDialogButtonBox.StandardButton.Ok|QDialogButtonBox.StandardButton.Cancel)
+
+    buttonBox.accepted.connect(diag.accept)
+    buttonBox.rejected.connect(diag.reject)
+    siz.addWidget(saveTbButton)
+    siz.addWidget(buttonBox)
+    diag.setLayout(siz)
+    diag.exec()
+
+    timeStamp = ''+ time.strftime("%d/%m/%y %H:%M:%S", time.localtime()) + ' ' + '\n'
+    logMsg = timeStamp + ''.join(tb)
+    logging.debug(logMsg)
+
 class mainWin(QMainWindow):
     def __init__(self, prm=None):
         QMainWindow.__init__(self)
@@ -71,18 +134,18 @@ class mainWin(QMainWindow):
         ##self.nTrials = 3
 
         try:
-            self.maxLevel = self.prm["phones"]["phonesMaxLevel"][self.prm["phones"]["phonesChoices"].index(self.prm["pref"]["sound"]["phones"])]
-        ##if all previously stored phones have been removed use the first of the new ones
+            self.maxLevel = self.prm["transducers"]["transducersMaxLevel"][self.prm["transducers"]["transducersChoices"].index(self.prm["pref"]["sound"]["transducers"])]
+        ##if all previously stored transducers have been removed use the first of the new ones
         except:
-            self.maxLevel = self.prm["phones"]["phonesMaxLevel"][0]
+            self.maxLevel = self.prm["transducers"]["transducersMaxLevel"][0]
 
 
         self.menubar = self.menuBar()
         self.fileMenu = self.menubar.addMenu(self.tr('-'))
         
-        self.editPhonesAction = QAction(QIcon.fromTheme("audio-headphones", QIcon(":/audio-headphones")), self.tr('Phones'), self)
-        self.fileMenu.addAction(self.editPhonesAction)
-        self.editPhonesAction.triggered.connect(self.onEditPhones)
+        self.editTransducersAction = QAction(QIcon.fromTheme("audio-headphones", QIcon(":/audio-headphones")), self.tr('Transducers'), self)
+        self.fileMenu.addAction(self.editTransducersAction)
+        self.editTransducersAction.triggered.connect(self.onEditTransducers)
         
         self.editPrefAction = QAction(QIcon.fromTheme("preferences-other", QIcon(":/preferences-other")), self.tr('Preferences'), self)
         self.fileMenu.addAction(self.editPrefAction)
@@ -163,7 +226,6 @@ class mainWin(QMainWindow):
         self.main_sizer.addLayout(self.grid1_sizer)
       
         self.cw.setLayout(self.main_sizer)
-    
 
         self.setCentralWidget(self.cw)
         self.show()
@@ -214,15 +276,15 @@ class mainWin(QMainWindow):
         ##print("Playing " + thisFName + " at " + str(lev) + " dB")
         snd, SF, nbits = self.audioManager.loadWavFile(thisFName, lev, self.maxLevel, channel="Original")
         
-        rms1 = sqrt(mean(snd[:,0]*snd[:,0]))
-        rms2 = sqrt(mean(snd[:,1]*snd[:,1]))
+        # rms1 = sqrt(mean(snd[:,0]*snd[:,0]))
+        # rms2 = sqrt(mean(snd[:,1]*snd[:,1]))
         # print("------------")
         # print(10*log10(rms1))
         # print(10*log10(rms2))
         
         self.trialRunning = True
         time.sleep(self.currLocale.toInt(self.prm['pref']['startDelay'])[0]/1000)
-        self.audioManager.playSound(snd, SF, 32, True, "snd_.wav")
+        self.audioManager.playSound(snd, SF, nbits, True, "snd_.wav")
         QApplication.processEvents()
         self.trialRunning = False
         self.statusButton.setText(self.tr("Next"))
@@ -333,18 +395,18 @@ class mainWin(QMainWindow):
         if dialog.exec():
             dialog.permanentApply()
             self.audioManager.initializeAudio()
-            self.maxLevel = self.prm["phones"]["phonesMaxLevel"][self.prm["phones"]["phonesChoices"].index(self.prm["pref"]["sound"]["phones"])]
-    def onEditPhones(self):
-        dialog = phonesDialog(self)
+            self.maxLevel = self.prm["transducers"]["transducersMaxLevel"][self.prm["transducers"]["transducersChoices"].index(self.prm["pref"]["sound"]["transducers"])]
+    def onEditTransducers(self):
+        dialog = transducersDialog(self)
         if dialog.exec():
             dialog.permanentApply()
-            ##if all previously stored phones have been removed use the first of the new ones
+            ##if all previously stored transducers have been removed use the first of the new ones
             try:
-                currPhoneIdx = self.prm["phones"]["phonesChoices"].index(self.prm["pref"]["sound"]["phones"])
+                currTransducerIdx = self.prm["transducers"]["transducersChoices"].index(self.prm["pref"]["sound"]["transducers"])
             except:
-                currPhoneIdx = 0
-            self.prm["pref"]["sound"]["phones"] = self.prm["phones"]["phonesChoices"][currPhoneIdx]
-            self.prm["phones"]["phonesMaxLevel"][self.prm["phones"]["phonesChoices"].index(self.prm["pref"]["sound"]["phones"])]
+                currTransducerIdx = 0
+            self.prm["pref"]["sound"]["transducers"] = self.prm["transducers"]["transducersChoices"][currTransducerIdx]
+            self.prm["transducers"]["transducersMaxLevel"][self.prm["transducers"]["transducersChoices"].index(self.prm["pref"]["sound"]["transducers"])]
 
     def onShowManualPdf(self):
         fileToOpen = os.path.abspath(os.path.dirname(__file__)) + '/doc/_build/latex/emid.pdf'
@@ -543,7 +605,9 @@ class responseLight(QWidget):
             qfont.fromString(self.cw.prm["pref"]["appearance"]["responseLightFont"])
             painter.setFont(qfont)
             painter.drawText(r, Qt.AlignmentFlag.AlignCenter, self.feedbackText)
-        
+
+
+
     
 def main():
     prm = {}
@@ -551,6 +615,7 @@ def main():
     prm = get_prefs(prm)
     prm = set_global_parameters(prm)
     qApp = QApplication(sys.argv)
+    sys.excepthook = excepthook
     #qApp.setWindowIcon(QtGui.QIcon(":/app_icon"))
  
 
@@ -587,6 +652,8 @@ def main():
     qApp.currentLocale = locale
     # instantiate the ApplicationWindow widget
     qApp.setApplicationName('emid')
+    if platform.system() == "Windows":
+        qApp.setStyle('Fusion')
     #qApp.setStyle('Breeze')
     x = mainWin(prm=prm)
     sys.exit(qApp.exec())
