@@ -108,15 +108,15 @@ class preferencesDialog(QDialog):
         #SOUND PREF
         soundPrefGrid = QGridLayout()
         n = 0
-        self.phonesChooser = QComboBox()
-        self.phonesChooser.addItems(self.parent().prm["phones"]["phonesChoices"])
-        currPhoneIdx = self.phonesChooser.findText(self.tmpPref['pref']['sound']['phones'])
-        if currPhoneIdx == -1:
-            currPhoneIdx = 0
-        self.phonesChooser.setCurrentIndex(currPhoneIdx)
-        self.phonesChooserLabel = QLabel(self.tr('Phones:'))
-        soundPrefGrid.addWidget(self.phonesChooserLabel, n, 0)
-        soundPrefGrid.addWidget(self.phonesChooser, n, 1)
+        self.transducersChooser = QComboBox()
+        self.transducersChooser.addItems(self.parent().prm["transducers"]["transducersChoices"])
+        currTransducerIdx = self.transducersChooser.findText(self.tmpPref['pref']['sound']['transducers'])
+        if currTransducerIdx == -1:
+            currTransducerIdx = 0
+        self.transducersChooser.setCurrentIndex(currTransducerIdx)
+        self.transducersChooserLabel = QLabel(self.tr('Transducers:'))
+        soundPrefGrid.addWidget(self.transducersChooserLabel, n, 0)
+        soundPrefGrid.addWidget(self.transducersChooser, n, 1)
         n = n+1
         
         self.playChooser = QComboBox()
@@ -285,7 +285,7 @@ class preferencesDialog(QDialog):
 
         ##self.tmpPref['pref']['general']['startupCommand'] = self.startupCommandWidget.text()
 
-        self.tmpPref['pref']['sound']['phones'] = self.phonesChooser.currentText()
+        self.tmpPref['pref']['sound']['transducers'] = self.transducersChooser.currentText()
         self.tmpPref['pref']['sound']['playCommand'] = self.tr(self.playCommandWidget.text())
         self.tmpPref['pref']['sound']['playCommandType'] = self.tr(self.playChooser.currentText())
         if self.parent().prm["appData"]["alsaaudioAvailable"] == True:
@@ -319,7 +319,7 @@ class preferencesDialog(QDialog):
         # self.startupCommandWidget.setText(self.tmpPref['pref']['general']['startupCommand'])
         
         self.playChooser.setCurrentIndex(self.playChooser.findText(self.tmpPref['pref']['sound']['playCommandType']))
-        self.phonesChooser.setCurrentIndex(self.phonesChooser.findText(self.tmpPref['pref']['sound']['phones']))
+        self.transducersChooser.setCurrentIndex(self.transducersChooser.findText(self.tmpPref['pref']['sound']['transducers']))
         if self.parent().prm["appData"]["alsaaudioAvailable"] == True:
             self.alsaaudioDeviceChooser.setCurrentIndex(self.alsaaudioDeviceChooser.findText(self.tmpPref['pref']['sound']['alsaaudioDevice']))
         if self.parent().prm["appData"]["pyaudioAvailable"] == True:
